<?php // error_reporting(E_ALL); ini_set('display_errors', 1); 
/**
*
* @package phpBB3 : style phpBB facebook
* @version 0.0.1
* @copyright (c) 2012 leviatan21	<leviatan21@gmail.com>
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
* Minimum Requirement: PHP 5.3.0
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
 * phpBB class that will be used in place of globalising these variables.
 */
class phpbb
{
	/** @var auth phpBB Auth class */
	public static $auth;
	/** @var db phpBB DBAL class */
	public static $db;
	/** @var template phpBB Template class */
	public static $template;
	/** @var user phpBB User class */
	public static $user;
	/** @var config phpBB Config settings */
	public static $config;
	/** @var page phpBB Current viewing page location */
	public static $page;
	/** @var $board_url Determine board url - we may need it later */
	public static $board_url;
	/** @var phpbb_root_path Current phpBB Path to the root folder */
	public static $phpbb_root_path;
	/** @var phpEx Current phpBB file extension for php files */
	public static $phpEx;

	/**
	 * Static Constructor.
	 */
	public static function initialise()
	{
		global $auth, $db, $template, $user;
		global $config, $phpbb_root_path, $phpEx;

		self::$auth				= &$auth;
		self::$config			= &$config;
		self::$db				= &$db;
		self::$template			= &$template;
		self::$user				= &$user;
		self::$board_url		= generate_board_url() . '/';
		self::$phpbb_root_path	= &$phpbb_root_path;
		self::$phpEx			= &$phpEx;
		self::$page 			= substr(self::$user->page['page_name'], 0, strpos(self::$user->page['page_name'], '.'));
	}
}

class phpbb_facebook_style
{
	/**
	 * Static Constructor.
	 */
	function __construct()
	{
		// Initialise phpBB
		phpbb::initialise();
		define('STYLE_FACEBOOK', true);
		if (!isset(phpbb::$user->lang['FRIENDS']))
		{
			phpbb::$user->add_lang(array('acp/common', 'mcp', 'ucp'));
		}
	}

	/**
	 * Static Destructor.
	 */
	function __destruct()
	{
		global $phpbb_hook;
		$phpbb_hook->remove_hook(array('template', 'display'), 'hook_phpbbfacebookstyle_display', 'last');
		return;
	}

	/**
	 * Initializate the main function colector
	 */
	public static function phpbb_facebook_style_init()
	{
		self::user_avatar();

		self::private_message();

		// Is this an email or an error page ?
		if (!isset(phpbb::$template->filename['body']) || phpbb::$template->filename['body'] == 'message_body.html')
		{
			return;
		}

		$fb_style_facebook_seo = new phpbb_facebook_seo();
		$fb_style_facebook_seo->seo_init();

		if (!in_array(phpbb::$page, array('index')))
		{
			self::statistics();
		}

		// Sessions expires in one hour : (default $config['session_length'] = 3600)
		//	3600 seconds in one hour = 60 segundos * 60 minutos
		$cookie_expire = (phpbb::$config['session_length']) ? (int) phpbb::$config['session_length'] : 3600;
		phpbb::$template->assign_vars(array(
			'POLL_ICON_IMG'			=> self::fb_imageset('icon_topic_attach', 'VIEW_TOPIC_POLL', 'POLL_ICON_IMG'),
			// For use within JavaScript
			'A_COOKIE_NAME'			=> phpbb::$config['cookie_name'] . '_',
			'A_COOKIE_SECURE'		=> (!phpbb::$config['cookie_secure']) ? 0 : 1,
			'A_COOKIE_EXPIRES'		=> (int) (($cookie_expire / 60) / 60),
			'L_CLICK_TO_VIEW_PM'	=> sprintf(phpbb::$user->lang['CLICK_VIEW_PRIVMSG'], '<a href="' . append_sid(phpbb::$phpbb_root_path . 'ucp.' . phpbb::$phpEx, 'i=pm&amp;folder=inbox') . '">', '</a>')
		));

		if (in_array(phpbb::$page, array('viewtopic')))
		{
			self::process_template_block('postrow', 'POSTER_AVATAR');
		}

		// Do not continue in UCP or MCP
		if (in_array(phpbb::$page, array('ucp', 'mcp')))
		{
			return;
		}

		// Get friends and foes
		self::zebra();
	}

	/**
	 * Set some stats, get posts count from forums data if we... hum... retrieve all forums data
	 */
	private static function statistics()
	{
		$total_posts	= phpbb::$config['num_posts'];
		$total_topics	= phpbb::$config['num_topics'];
		$total_users	= phpbb::$config['num_users'];

		$l_total_user_s = ($total_users == 0) ? 'TOTAL_USERS_ZERO' : 'TOTAL_USERS_OTHER';
		$l_total_post_s = ($total_posts == 0) ? 'TOTAL_POSTS_ZERO' : 'TOTAL_POSTS_OTHER';
		$l_total_topic_s = ($total_topics == 0) ? 'TOTAL_TOPICS_ZERO' : 'TOTAL_TOPICS_OTHER';

		// Grab group details for legend display
		if (phpbb::$auth->acl_gets('a_group', 'a_groupadd', 'a_groupdel'))
		{
			$sql = 'SELECT group_id, group_name, group_colour, group_type
				FROM ' . GROUPS_TABLE . '
				WHERE group_legend = 1
				ORDER BY group_name ASC';
		}
		else
		{
			$sql = 'SELECT g.group_id, g.group_name, g.group_colour, g.group_type
				FROM ' . GROUPS_TABLE . ' g
				LEFT JOIN ' . USER_GROUP_TABLE . ' ug
					ON (
						g.group_id = ug.group_id
						AND ug.user_id = ' . phpbb::$user->data['user_id'] . '
						AND ug.user_pending = 0
					)
				WHERE g.group_legend = 1
					AND (g.group_type <> ' . GROUP_HIDDEN . ' OR ug.user_id = ' . phpbb::$user->data['user_id'] . ')
				ORDER BY g.group_name ASC';
		}
		$result = phpbb::$db->sql_query($sql);

		$legend = array();
		while ($row = phpbb::$db->sql_fetchrow($result))
		{
			$colour_text = ($row['group_colour']) ? ' style="color:#' . $row['group_colour'] . '"' : '';
			$group_name = ($row['group_type'] == GROUP_SPECIAL) ? phpbb::$user->lang['G_' . $row['group_name']] : $row['group_name'];

			if ($row['group_name'] == 'BOTS' || (phpbb::$user->data['user_id'] != ANONYMOUS && !phpbb::$auth->acl_get('u_viewprofile')))
			{
				$legend[] = '<span' . $colour_text . '>' . $group_name . '</span>';
			}
			else
			{
				$legend[] = '<a' . $colour_text . ' href="' . append_sid(phpbb::$phpbb_root_path . 'memberlist.' . phpbb::$phpEx, 'mode=group&amp;g=' . $row['group_id']) . '">' . $group_name . '</a>';
			}
		}
		phpbb::$db->sql_freeresult($result);

		$legend = implode(', ', $legend);

		// Generate birthday list if required ...
		$birthday_list = '';
		if (phpbb::$config['load_birthdays'] && phpbb::$config['allow_birthdays'] && phpbb::$auth->acl_gets('u_viewprofile', 'a_user', 'a_useradd', 'a_userdel'))
		{
			$now = phpbb_gmgetdate(time() + phpbb::$user->timezone + phpbb::$user->dst);

			// Display birthdays of 29th february on 28th february in non-leap-years
			$leap_year_birthdays = '';
			if ($now['mday'] == 28 && $now['mon'] == 2 && !phpbb::$user->format_date(time(), 'L'))
			{
				$leap_year_birthdays = " OR user_birthday LIKE '" . phpbb::$db->sql_escape(sprintf('%2d-%2d-', 29, 2)) . "%'";
			}

			$sql = 'SELECT u.user_id, u.username, u.user_colour, u.user_birthday
				FROM ' . USERS_TABLE . ' u
				LEFT JOIN ' . BANLIST_TABLE . " b ON (u.user_id = b.ban_userid)
				WHERE (b.ban_id IS NULL
					OR b.ban_exclude = 1)
					AND (u.user_birthday LIKE '" . phpbb::$db->sql_escape(sprintf('%2d-%2d-', $now['mday'], $now['mon'])) . "%' $leap_year_birthdays)
					AND u.user_type IN (" . USER_NORMAL . ', ' . USER_FOUNDER . ')';
			$result = phpbb::$db->sql_query($sql);

			while ($row = phpbb::$db->sql_fetchrow($result))
			{
				$birthday_list .= (($birthday_list != '') ? ', ' : '') . get_username_string('full', $row['user_id'], $row['username'], $row['user_colour']);

				if ($age = (int) substr($row['user_birthday'], -4))
				{
					$birthday_list .= ' (' . max(0, $now['year'] - $age) . ')';
				}
			}
			phpbb::$db->sql_freeresult($result);
		}

		// Assign index specific vars
		phpbb::$template->assign_vars(array(
			'TOTAL_POSTS'	=> sprintf(phpbb::$user->lang[$l_total_post_s], $total_posts),
			'TOTAL_TOPICS'	=> sprintf(phpbb::$user->lang[$l_total_topic_s], $total_topics),
			'TOTAL_USERS'	=> sprintf(phpbb::$user->lang[$l_total_user_s], $total_users),
			'NEWEST_USER'	=> sprintf(phpbb::$user->lang['NEWEST_USER'], get_username_string('full', phpbb::$config['newest_user_id'], phpbb::$config['newest_username'], phpbb::$config['newest_user_colour'])),

			'LEGEND'		=> $legend,
			'BIRTHDAY_LIST'	=> $birthday_list,
		));
	}

	/**
	 * Set the user avatar for the header/sidebar
	 */
	private static function user_avatar()
	{
		phpbb::$template->assign_vars(array(
			'STYLEFB_USER_NAME'			=> phpbb::$user->data['username'],
			'STYLEFB_DEFAULT_AVATAR'	=> (phpbb::$user->data['user_avatar']) ? false : true,
			'STYLEFB_USER_AVATAR'		=> (phpbb::$user->optionget('viewavatars')) ? self::get_avatar() : '',
		));
	}

	/**
	 * Set the user avatar, if it have, else set a default image
	 *
	 * @return (string)		image html tag
	 */
	private static function get_avatar($title = 'USER_AVATAR')
	{
		// Generate the appropriate user information for the user we are looking at
		if (!function_exists('get_user_avatar'))
		{
			include(phpbb::$phpbb_root_path . 'includes/functions_display.' . phpbb::$phpEx);
		}

		$user_avatar		= (isset(phpbb::$user->data['user_avatar']) && phpbb::$user->data['user_avatar'] != '') ? phpbb::$user->data['user_avatar'] : phpbb::$phpbb_root_path . 'styles/phpbbfacebook/imageset/fb_avatar.png';
		$user_avatar_type	= (isset(phpbb::$user->data['user_avatar_type']) && phpbb::$user->data['user_avatar_type'] != 0) ? phpbb::$user->data['user_avatar_type'] : AVATAR_REMOTE;
		$user_avatar_width	= (isset(phpbb::$user->data['user_avatar_width']) && phpbb::$user->data['user_avatar_width'] != 0) ? phpbb::$user->data['user_avatar_width'] : 0;
		$user_avatar_height	= (isset(phpbb::$user->data['user_avatar_height']) && phpbb::$user->data['user_avatar_height'] != 0) ? phpbb::$user->data['user_avatar_height'] : 0;

		$style_facebook_avatar = get_user_avatar($user_avatar, $user_avatar_type, $user_avatar_width, $user_avatar_height, $title, true);

		$style_facebook_avatar = preg_replace('/width=\"(.*?)\"/is', '', $style_facebook_avatar);
		$style_facebook_avatar = preg_replace('/height=\"(.*?)\"/is', 'class="uiProfilePhoto headerTinymanPhoto uiProfilePhotoLarge img"', $style_facebook_avatar);

		return $style_facebook_avatar;
	}

	/**
	 * Get friends/foe users and status
	 */
	private static function zebra()
	{
		// Output listing of friends (online & offline)
		$update_time = phpbb::$config['load_online_time'] * 60;

		$sql = phpbb::$db->sql_build_query('SELECT_DISTINCT', array(
			'SELECT'	=> 'u.user_id, u.username, u.username_clean, u.user_colour, u.user_allow_pm, MAX(s.session_time) as online_time, MIN(s.session_viewonline) AS viewonline',
			'FROM'		=> array(
				USERS_TABLE		=> 'u',
				ZEBRA_TABLE		=> 'z'
			),
			'LEFT_JOIN'	=> array(
				array(
					'FROM'	=> array(SESSIONS_TABLE => 's'),
					'ON'	=> 's.session_user_id = z.zebra_id'
				)
			),
			'WHERE'		=> 'z.user_id = ' . phpbb::$user->data['user_id'] . '
				AND z.friend = 1
				AND u.user_id = z.zebra_id',
			'GROUP_BY'	=> 'z.zebra_id, u.user_id, u.username_clean, u.user_colour, u.username',
			'ORDER_BY'	=> 'u.username_clean ASC',
		));
		$result = phpbb::$db->sql_query($sql);

		while ($row = phpbb::$db->sql_fetchrow($result))
		{
			$which = (time() - $update_time < $row['online_time'] && ($row['viewonline'] || phpbb::$auth->acl_get('u_viewonline'))) ? 'online' : 'offline';

			$title = ($which == 'online') ? 'ONLINE' : 'OFFLINE';
			phpbb::$template->assign_block_vars('fb_friends', array(
				'USER_STATUS'	=> $which,
				'USER_ID'		=> $row['user_id'],
				'PROFILE_URL'	=> append_sid(phpbb::$phpbb_root_path . 'memberlist.' .phpbb::$phpEx, array('mode' => 'viewprofile', 'u', $row['user_id'])),
				'USER_NAME'		=> get_username_string('username', $row['user_id'], $row['username']),
				'USER_AVATAR'	=> (phpbb::$user->optionget('viewavatars')) ? self::get_avatar($title) : '',
				'U_USER_PM'		=> (phpbb::$config['allow_privmsg'] && phpbb::$auth->acl_get('u_sendpm') && ($row['user_allow_pm'] || phpbb::$auth->acl_gets('a_', 'm_') || phpbb::$auth->acl_getf_global('m_'))) ? append_sid(phpbb::$phpbb_root_path . 'ucp.' . phpbb::$phpEx, 'i=pm&amp;mode=compose&amp;u=' . $row['user_id']) : '',
			));
		}
		phpbb::$db->sql_freeresult($result);
	}

	/**
	 * Find how many unread PM have the user
	 */
	private static function private_message()
	{
		$l_message_unread = (phpbb::$user->data['user_unread_privmsg'] == 1) ? phpbb::$user->lang['UNREAD_PM'] : phpbb::$user->lang['UNREAD_PMS'];
		$l_privmsgs_text_unread = sprintf($l_message_unread, phpbb::$user->data['user_unread_privmsg']);

		phpbb::$template->assign_vars(array(
			'S_UNREAD_PM'	=> phpbb::$user->data['user_unread_privmsg'],
			'L_UNREAD_PM'	=> $l_privmsgs_text_unread,
		));
	}

	/**
	* Process template blocks
	*/
	private static function process_template_block($block_name, $block_section)
	{
		$avatars = array();
		if (!empty($block_name) && !empty($block_section))
		{
			if (!empty(phpbb::$template->_tpldata[$block_name]))
			{
				foreach (phpbb::$template->_tpldata[$block_name] as $row => $data)
				{
					if (empty($data[$block_section]))
					{
						if (!isset($avatars[$data['POSTER_ID']]))
						{
							$avatars[$data['POSTER_ID']] = self::get_avatar();
							$data[$block_section] = $avatars[$data['POSTER_ID']];
						}
						else
						{
							$data[$block_section] = $avatars[$data['POSTER_ID']];
						}
						// Alter the array
						phpbb::$template->alter_block_array($block_name, array(
							$block_section		=> $data[$block_section] . '<br />',
						), $row, 'change');
					}
				}
			}
		}
	}

	/**
	* Some missing images from the imageset.cfg
	*/
	function fb_imageset($img = 'all', $lang_var = '')
	{
		static $imageset = array();

		if (empty($imageset))
		{
			$imageset = array(
				'icon_topic_attach' => array(
					'image_file_name' 				=> 'icon_topic_poll.gif'
				)
			);
		}

		foreach ($imageset as $image => $img_data)
		{
			if ($img == $image)
			{
				$alt = (!empty(phpbb::$user->lang[$lang_var])) ? phpbb::$user->lang[$lang_var] : $lang_var;
				$imagedata = '<img src="' . phpbb::$phpbb_root_path . 'styles/phpbbfacebook/imageset/' . $img_data['image_file_name'] . '"'  . ' alt="' . $alt . '" title="' . $alt . '" />';
				break;
			}
		}
		return $imagedata;
	}
}

/**
 * Class Seo
 */
class phpbb_facebook_seo
{
	public static $url_separator;
	public static $param_separator;
	public static $extension;
	public static $zebra;

	/**
	 * Static Constructor
	 */
	function __construct()
    {
		self::$url_separator = '-';
		self::$param_separator = '_';
		self::$extension = '.html';
    }

    /**
     * Static Destructor.
     */
	function __destruct()
    {}

    /**
     * Initializate the main function colector
     */
	public static function seo_init()
	{
		self::metatags();

		switch (phpbb::$page)
		{
			case 'viewforum':
				self::viewforum_statistics();
			break;
			case 'viewtopic':
				self::viewtopic_statistics();
			break;
		}

		// Do not continue in UCP or MCP
		if (in_array(phpbb::$page, array('ucp', 'mcp')))
		{
			return;
		}

		self::random_topics(phpbb::$config['topics_per_page']);
		
		// Do not continue in search
		if (!in_array(phpbb::$page, array('search')))
		{
			self::active_topics(phpbb::$config['topics_per_page']);
		}
	}

	/**
	 * Set the keywords/description metatags with forums/topics data
	 */
	private static function metatags()
	{
		$seo_keywords = (isset(phpbb::$template->_rootref['PAGE_TITLE'])) ? phpbb::$template->_rootref['PAGE_TITLE'] . ' ' : '';
		$seo_description = '';

		//	category/forum
		if (isset(phpbb::$template->_tpldata['forumrow']))
		{
			foreach (phpbb::$template->_tpldata['forumrow'] as $forumrow)
			{
				if ($forumrow['FORUM_NAME'] != '')
				{
					$seo_keywords .= trim(strip_tags($forumrow['FORUM_NAME'])) . ' ';
				}
				if ($forumrow['FORUM_DESC'] != '')
				{
					$seo_description .= trim(strip_tags($forumrow['FORUM_DESC'])) . ' ';
				}
			}
		}
		//	topics
		else
		{
			if (isset(phpbb::$template->_rootref['FORUM_NAME']))
			{
				$seo_keywords .= trim(strip_tags(phpbb::$template->_rootref['FORUM_NAME'])) . ' ';
			}
			if (isset(phpbb::$template->_rootref['TOPIC_TITLE']))
			{
				$seo_description .= trim(strip_tags(phpbb::$template->_rootref['TOPIC_TITLE'])) . ' ';
			}
		}

		//	At the end add the proper config values
		$seo_keywords .= phpbb::$config['sitename'];
		$seo_description .= phpbb::$config['site_desc'];

		//	Split the arrays by spaces
		$seo_keywords 	 = preg_split('/ /', $seo_keywords, 0, PREG_SPLIT_NO_EMPTY);
		$seo_description = preg_split('/ /', $seo_description, 0, PREG_SPLIT_NO_EMPTY);

		//	Sort the array with longer text at top
		usort($seo_keywords, 'self::sort_by_longer');
		//	Sort the array with longer text at top
		usort($seo_description, 'self::sort_by_longer');

		//	Only take the maximun amount of 5 items form the array
		$seo_keywords 	 = array_slice($seo_keywords, 0, 5);
		//	Only take the maximun amount of 160 items form the array
		$seo_description = array_slice($seo_description, 0, 160);

		phpbb::$template->assign_vars(array(
			'FB_SEO_KEYWORDS'		=> implode(', ', $seo_keywords),
			'FB_SEO_DESCRIPTION'	=> implode(', ', $seo_description),
			// http://developers.facebook.com/docs/reference/plugins/like/
			// http://developers.facebook.com/docs/opengraphprotocol/#extra-data
			'FB_ID'					=> '155518934562000',
			'FB_TYPE'				=> 'article',									
			'FB_SEO_BASE_URL'		=> phpbb::$board_url,
			'FB_SITE_NAME'			=> phpbb::$config['sitename'],
			'FB_SITE_DESCRIPTION'	=> phpbb::$config['site_desc'],
			'FB_SITE_LOGO_SRC'		=> phpbb::$user->img('site_logo', '', false, '', 'src'),
			// http://support.google.com/webmasters/bin/answer.py?hl=en&answer=35659
			'GOOGLE_VERIFY'			=> ''
		));
	}

	/**
	 * Sort the array with longer text at top
	 *	Source: http://www.php.net/manual/en/function.usort.php#108116
	 * @param (string)	$a			the word to compare with 
	 * @param (string)	$b			the word to compare against 
	 * @return (int)	0/-1/1		if $b is longer than $a
	 */
	function sort_by_longer($a, $b)
	{
		$a = strtolower($a);
		$b = strtolower($b);

		//	a ($a) is same priority as b ($b), keeping the same
		if (strlen($a) == strlen($b))
		{
			return 0;
		}
		//	a ($a) is higher priority than b ($b), moving b down array
		else if (strlen($a) > strlen($b))
		{
			return -1;
		}
		//	b ($b) is higher priority than a ($a), moving b up array
		else
		{
			return 1;
		}

		//	The shot version for this function should be a single line
		return strlen($b) - strlen($a);
	}

	/**
	 * Get statistics about category/forums for the right sidebar
	 */
	private static function viewforum_statistics()
	{
		// It's a category
		if (isset(phpbb::$template->_tpldata['forumrow']))
		{
			phpbb::$template->assign_block_vars('category_statistics', array(
				'FORUM_ID'				=> phpbb::$template->_rootref['FORUM_ID'],
				'FORUM_NAME'			=> phpbb::$template->_rootref['FORUM_NAME'],
				'FORUM_DESC'			=> phpbb::$template->_rootref['FORUM_DESC'],
				'U_VIEW_FORUM'			=> phpbb::$template->_rootref['U_VIEW_FORUM'],
				'LOGGED_IN_USER_LIST'	=> phpbb::$template->_rootref['LOGGED_IN_USER_LIST'],
				'S_DISPLAY_ONLINE_LIST'	=> phpbb::$template->_rootref['S_DISPLAY_ONLINE_LIST'],

				'TOTAL_FORUMS'			=> sizeof(phpbb::$template->_tpldata['forumrow']),
				'U_MARK_FORUMS'			=> phpbb::$template->_rootref['U_MARK_FORUMS'],
			));
		}
		else
		{
			phpbb::$template->assign_block_vars('forum_statistics', array(
				'FORUM_ID'				=> phpbb::$template->_rootref['FORUM_ID'],
				'FORUM_NAME'			=> phpbb::$template->_rootref['FORUM_NAME'],
				'FORUM_DESC'			=> phpbb::$template->_rootref['FORUM_DESC'],
				'U_VIEW_FORUM'			=> phpbb::$template->_rootref['U_VIEW_FORUM'],
				'LOGGED_IN_USER_LIST'	=> phpbb::$template->_rootref['LOGGED_IN_USER_LIST'],
				'S_DISPLAY_ONLINE_LIST'	=> phpbb::$template->_rootref['S_DISPLAY_ONLINE_LIST'],

				'TOTAL_TOPICS'			=> phpbb::$template->_rootref['TOTAL_TOPICS'],
				'U_POST_NEW_TOPIC'		=> phpbb::$template->_rootref['U_POST_NEW_TOPIC'],
				'U_MCP'					=> phpbb::$template->_rootref['U_MCP'],
				'U_MARK_TOPICS'			=> phpbb::$template->_rootref['U_MARK_TOPICS'],
			));
		}
	}

	/**
	 * Get statistics about topics
	 */
	private static function viewtopic_statistics()
	{
		if (isset(phpbb::$template->_tpldata['postrow']))
		{
			phpbb::$template->assign_block_vars('viewtopic_statistics', array(
				'FORUM_ID'				=> phpbb::$template->_rootref['FORUM_ID'],
				'FORUM_NAME'			=> phpbb::$template->_rootref['FORUM_NAME'],
				'FORUM_DESC'			=> phpbb::$template->_rootref['FORUM_DESC'],
				'U_VIEW_FORUM'			=> phpbb::$template->_rootref['U_VIEW_FORUM'],
				'TOPIC_ID'				=> phpbb::$template->_rootref['TOPIC_ID'],
				'TOPIC_TITLE'			=> phpbb::$template->_rootref['TOPIC_TITLE'],
				'U_VIEW_TOPIC'			=> phpbb::$template->_rootref['U_VIEW_TOPIC'],
				'TOTAL_POSTS'			=> phpbb::$template->_rootref['TOTAL_POSTS'],
				'LOGGED_IN_USER_LIST'	=> phpbb::$template->_rootref['LOGGED_IN_USER_LIST'],
				'S_DISPLAY_ONLINE_LIST'	=> phpbb::$template->_rootref['S_DISPLAY_ONLINE_LIST'],
				'U_MCP'					=> phpbb::$template->_rootref['U_MCP'],
			));
			phpbb::$template->_rootref['S_DISPLAY_ONLINE_LIST'] = false;
		}
	}

	/** 
	 * Get a list of topics for the right sidebar
	 **/
	private static function random_topics($limit = 10)
	{
		global $phpbb_seo;

		$sql_array = array(
			'SELECT' => 'COUNT(topic_id) as num_topics',
			'FROM' => array(
				TOPICS_TABLE => 't',
			),
			'WHERE' => phpbb::$db->sql_in_set('forum_id', array_keys(phpbb::$auth->acl_getf('f_read', true)))
		);
		$sql = phpbb::$db->sql_build_query('SELECT', $sql_array);
		$result = phpbb::$db->sql_query($sql);
		$style_facebook_num_topics = $num_topics = phpbb::$db->sql_fetchfield('num_topics');
		phpbb::$db->sql_freeresult($result);

		$style_facebook_num_posts = (isset(phpbb::$config['style_facebook_num_posts'])) ? phpbb::$config['style_facebook_num_posts'] : 0;
		$style_facebook_num_posts = ($style_facebook_num_posts+phpbb::$config['topics_per_page'] >= $style_facebook_num_topics) ? 0 : $style_facebook_num_posts;

		$sql_array = array(
			'SELECT' => 'f.*, t.*, u.username, u.user_colour',

			'FROM' => array(
				TOPICS_TABLE => 't',
			),

			'LEFT_JOIN' => array(
				array(
					'FROM' => array(USERS_TABLE => 'u'),
					'ON' => 'u.user_id = t.topic_poster',
				),
				array(
					'FROM' => array(FORUMS_TABLE => 'f'),
					'ON' => 't.forum_id = f.forum_id',
				),
			),

			'WHERE' => phpbb::$db->sql_in_set('t.forum_id', array_keys(phpbb::$auth->acl_getf('f_read', true))) . '
				AND t.topic_id > ' . (int) $style_facebook_num_posts . '
				AND t.topic_status <> ' . ITEM_MOVED . '
				AND t.topic_approved = 1
				OR t.forum_id = 0', //OR t.forum_id = 0, esta linea es para que muestre tambien los globales ya que el id del foro de estos es 0

			'ORDER_BY' => 't.topic_id ASC',
		);
		$sql = phpbb::$db->sql_build_query('SELECT', $sql_array);
		$result = phpbb::$db->sql_query_limit($sql, $limit);
		$rows = array();
		while ($row = phpbb::$db->sql_fetchrow($result))
		{
			$rows[] = $row;
		}
		phpbb::$db->sql_freeresult($result);

		shuffle($rows);
		foreach ($rows as $row)
		{
			$forum_id = $row['forum_id'];

			// www.phpBB-SEO.com SEO TOOLKIT BEGIN
			if (class_exists('phpbb_seo'))
			{
				$phpbb_seo->set_url(!empty($row['forum_name']), $forum_id, $phpbb_seo->seo_static['forum']);
				$phpbb_seo->prepare_iurl($row, 'topic', $row['topic_type'] == POST_GLOBAL ? $phpbb_seo->seo_static['global_announce'] : $phpbb_seo->seo_url['forum'][$forum_id]);
			}
			// www.phpBB-SEO.com SEO TOOLKIT END

			phpbb::$template->assign_block_vars('last_topics_on_index', array(
				'TOPIC_TITLE'		=> censor_text($row['topic_title']),
			//	'TOPIC_AUTHOR_FULL'	=> get_username_string('full', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),
				'TOPIC_AUTHOR_NAME'	=> get_username_string('username', $row['topic_poster'], $row['topic_first_poster_name']),
				'TOPIC_DATE'		=> phpbb::$user->format_date($row['topic_time']),
				'TOPIC_LINK'		=> append_sid(phpbb::$phpbb_root_path . 'viewtopic.' . phpbb::$phpEx, 'f=' . $row['forum_id'] . '&amp;t=' . $row['topic_id']),
				'TOPIC_REPLIES'		=> $row['topic_replies'],
			));
			$style_facebook_num_posts = $row['topic_id'];
		}

		phpbb::$template->assign_vars(array(
			'TOTAL_RANDOM_TOPICS'	=> sizeof($rows),
			'GO_TOPIC_IMG'			=> phpbb::$user->img('icon_topic_latest', 'VIEW_TOPIC'),
		));

		$style_facebook_num_posts = ($style_facebook_num_posts+phpbb::$config['topics_per_page'] >= $style_facebook_num_topics) ? 0 : $style_facebook_num_posts;
		set_config('style_facebook_num_posts', (int) $style_facebook_num_posts, true);
	}

	private static function active_topics($limit = 10, $sort_days = 7)
	{
		// Define some vars
		$start = max(request_var('start', 0), 0);
		$show_results = 'topics';
		$sort_key = 't';
		$sort_dir = 'd';
		$id_ary = array();

		// Which forums should not be searched? Author searches are also carried out in unindexed forums
		$ex_fid_ary = array_unique(array_merge(array_keys(phpbb::$auth->acl_getf('!f_read', true)), array_keys(phpbb::$auth->acl_getf('!f_search', true))));

		// find out in which forums the user is allowed to view approved posts
		if (phpbb::$auth->acl_get('m_approve'))
		{
			$m_approve_fid_ary = array(-1);
			$m_approve_fid_sql = '';
		}
		else if (phpbb::$auth->acl_getf_global('m_approve'))
		{
			$m_approve_fid_ary = array_diff(array_keys(phpbb::$auth->acl_getf('!m_approve', true)), $ex_fid_ary);
			$m_approve_fid_sql = ' AND (p.post_approved = 1' . ((sizeof($m_approve_fid_ary)) ? ' OR ' . phpbb::$db->sql_in_set('p.forum_id', $m_approve_fid_ary, true) : '') . ')';
		}
		else
		{
			$m_approve_fid_ary = array();
			$m_approve_fid_sql = ' AND p.post_approved = 1';
		}

		$last_post_time_sql = ($sort_days) ? ' AND t.topic_last_post_time > ' . (time() - ($sort_days * 24 * 3600)) : '';

		$sql = 'SELECT t.topic_last_post_time, t.topic_id
			FROM ' . TOPICS_TABLE . " t
			WHERE t.topic_moved_id = 0
				$last_post_time_sql
				" . str_replace(array('p.', 'post_'), array('t.', 'topic_'), $m_approve_fid_sql) . '
				' . ((sizeof($ex_fid_ary)) ? ' AND ' . phpbb::$db->sql_in_set('t.forum_id', $ex_fid_ary, true) : '') . '
			ORDER BY t.topic_last_post_time DESC';

		$field = 'topic_id';

		// show_results should not change after this
		$per_page = ($show_results == 'posts') ? phpbb::$config['posts_per_page'] : phpbb::$config['topics_per_page'];
		$total_match_count = 0;

		// only return up to 1000 ids (the last one will be removed later)
		$result = phpbb::$db->sql_query_limit($sql, $limit - $start, $start);

		while ($row = phpbb::$db->sql_fetchrow($result))
		{
			$id_ary[] = (int) $row[$field];
		}
		phpbb::$db->sql_freeresult($result);

		if (!sizeof($id_ary) || ($sort_days < 90 && sizeof($id_ary) < $limit))
		{
			return self::active_topics($limit, $sort_days += 7);
		}

		$total_match_count = sizeof($id_ary) + $start;
		$id_ary = array_slice($id_ary, 0, $per_page);

		// make sure that some arrays are always in the same order
		sort($ex_fid_ary);
		sort($m_approve_fid_ary);

		if (!isset(phpbb::$user->lang['ACTIVE_TOPICS']))
		{
			phpbb::$user->add_lang('viewforum');
		}

		$sql_where  = phpbb::$db->sql_in_set('t.topic_id', $id_ary);
		$sql_where .= (sizeof($ex_fid_ary)) ? ' AND (' . phpbb::$db->sql_in_set('f.forum_id', $ex_fid_ary, true) . ' OR f.forum_id IS NULL)' : '';

		$sql = 'SELECT t.*
			FROM ' . TOPICS_TABLE . ' t
			WHERE ' . $sql_where . '
			ORDER BY t.topic_last_post_time DESC';
		$result = phpbb::$db->sql_query($sql);

		$rowset = array();
		while ($row = phpbb::$db->sql_fetchrow($result))
		{
			$rowset[] = $row;
		}
		phpbb::$db->sql_freeresult($result);

		foreach ($rowset as $row)
		{
			phpbb::$template->assign_block_vars('fb_active_topics', array(
				'TOTAL_MATCHES'		=> sizeof($id_ary),
				'FORUM_ID'			=> $row['forum_id'],
				'TOPIC_ID'			=> $row['topic_id'],
				'TOPIC_TITLE'		=> censor_text($row['topic_title']),
				'TOPIC_REPLIES'		=> (phpbb::$auth->acl_get('m_approve', $row['forum_id'])) ? $row['topic_replies_real'] : $row['topic_replies'],
				'TOPIC_VIEWS'		=> $row['topic_views'],
				'TOPIC_AUTHOR'		=> get_username_string('username', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),
				'FIRST_POST_TIME'	=> phpbb::$user->format_date($row['topic_time']),
				'U_VIEW_TOPIC'		=> append_sid(phpbb::$phpbb_root_path . 'viewtopic.' . phpbb::$phpEx, "f={$row['forum_id']}&amp;t={$row['topic_id']}&amp;view=unread") . '#unread',	
			));
		}

		phpbb::$template->assign_var('TOTAL_ACTIVE_TOPICS', sizeof($id_ary));

		unset($ex_fid_ary, $m_approve_fid_ary, $m_approve_fid_sql, $id_ary, $rowset);
	}

	/**
	 * Enter description here...
	 *	@view http://forobeta.com/php/46671-convertir-o-pasar-texto-url-search-engine-optimization-amigable.html#post481136
	 * @param unknown_type $string
	 * @param unknown_type $replacement
	 * @param unknown_type $map
	 * @return unknown
	 */
	private static function slug($string, $replacement = '-', $map = array())
	{
		if (is_array($replacement))
		{
			$map = $replacement;
			$replacement = '+';
		}
		$quotedReplacement = preg_quote($replacement, '/');

		$merge = array(
			'/[^\s\p{Ll}\p{Lm}\p{Lo}\p{Lt}\p{Lu}\p{Nd}]/mu'						=> ' ',
			'/\\s+/'															=> $replacement,
			sprintf('/^[%s]+|[%s]+$/', $quotedReplacement, $quotedReplacement)	=> '',
		);

		$_transliteration = array(
			'/ä|æ|ǽ/'							=> 'ae',
			'/ö|œ/'								=> 'oe',
			'/ü/'								=> 'ue',
			'/Ä/'								=> 'Ae',
			'/Ü/'								=> 'Ue',
			'/Ö/'								=> 'Oe',
			'/À|Á|Â|Ã|Ä|Å|Ǻ|Ā|Ă|Ą|Ǎ/'			=> 'A',
			'/à|á|â|ã|å|ǻ|ā|ă|ą|ǎ|ª/'			=> 'a',
			'/Ç|Ć|Ĉ|Ċ|Č/'						=> 'C',
			'/ç|ć|ĉ|ċ|č/'						=> 'c',
			'/Ð|Ď|Đ/'							=> 'D',
			'/ð|ď|đ/'							=> 'd',
			'/È|É|Ê|Ë|Ē|Ĕ|Ė|Ę|Ě/'				=> 'E',
			'/è|é|ê|ë|ē|ĕ|ė|ę|ě/'				=> 'e',
			'/Ĝ|Ğ|Ġ|Ģ/'							=> 'G',
			'/ĝ|ğ|ġ|ģ/'							=> 'g',
			'/Ĥ|Ħ/'								=> 'H',
			'/ĥ|ħ/'								=> 'h',
			'/Ì|Í|Î|Ï|Ĩ|Ī|Ĭ|Ǐ|Į|İ/'				=> 'I',
			'/ì|í|î|ï|ĩ|ī|ĭ|ǐ|į|ı/'				=> 'i',
			'/Ĵ/'								=> 'J',
			'/ĵ/'								=> 'j',
			'/Ķ/'								=> 'K',
			'/ķ/'								=> 'k',
			'/Ĺ|Ļ|Ľ|Ŀ|Ł/'						=> 'L',
			'/ĺ|ļ|ľ|ŀ|ł/'						=> 'l',
			'/Ñ|Ń|Ņ|Ň/'							=> 'N',
			'/ñ|ń|ņ|ň|ŉ/'						=> 'n',
			'/Ò|Ó|Ô|Õ|Ō|Ŏ|Ǒ|Ő|Ơ|Ø|Ǿ/'			=> 'O',
			'/ò|ó|ô|õ|ō|ŏ|ǒ|ő|ơ|ø|ǿ|º/'			=> 'o',
			'/Ŕ|Ŗ|Ř/'							=> 'R',
			'/ŕ|ŗ|ř/'							=> 'r',
			'/Ś|Ŝ|Ş|Š/'							=> 'S',
			'/ś|ŝ|ş|š|ſ/'						=> 's',
			'/Ţ|Ť|Ŧ/'							=> 'T',
			'/ţ|ť|ŧ/'							=> 't',
			'/Ù|Ú|Û|Ũ|Ū|Ŭ|Ů|Ű|Ų|Ư|Ǔ|Ǖ|Ǘ|Ǚ|Ǜ/'	=> 'U',
			'/ù|ú|û|ũ|ū|ŭ|ů|ű|ų|ư|ǔ|ǖ|ǘ|ǚ|ǜ/'	=> 'u',
			'/Ý|Ÿ|Ŷ/'							=> 'Y',
			'/ý|ÿ|ŷ/'							=> 'y',
			'/Ŵ/'								=> 'W',
			'/ŵ/'								=> 'w',
			'/Ź|Ż|Ž/'							=> 'Z',
			'/ź|ż|ž/'							=> 'z',
			'/Æ|Ǽ/'								=> 'AE',
			'/ß/'								=> 'ss',
			'/Ĳ/'								=> 'IJ',
			'/ĳ/'								=> 'ij',
			'/Œ/'								=> 'OE',
			'/ƒ/'								=> 'f'
		);
		
		$map = $map + $_transliteration + $merge;
		return preg_replace(array_keys($map), array_values($map), $string);
	}

	/**
	 * Enter description here...
	 *
	 * @param unknown_type $string
	 * @param unknown_type $params
	 * @return unknown
	 */
	public static function build_url($string, $params = array())
	{
		$string = self::slug($string);
		$string = truncate_string($string, 60);
		$string = strtolower($string);

		$url = phpbb::$board_url . $string;

		if (substr($url, -1) != '/')
		{
			$url .= '/';
		}

		$last = sizeof($params);
		$count = 0;
		foreach ($params as $name => $value)
		{
			$url .= trim($name) . self::$param_separator . trim($value);
			$count++;
			if ($count < $last) { $url .= self::$url_separator; }
		}

		$url .= self::$extension;

		return strtolower($url);
	}
}

/**
 * Enter description here...
 */
function hook_phpbbfacebookstyle_display($phpbb_hook, $handle)
{
	// fix for bug: http://tracker.phpbb.com/browse/PHPBB3-9842
	if ($handle != 'body') { return; }

	// Quick Reply pseudo hook :)
	hook_phpbbfacebookstyle_quickreply();

	$phpbb_facebook_style = new phpbb_facebook_style();
	$phpbb_facebook_style->phpbb_facebook_style_init();
}

/**
 * Quick redirect after submit the quick reply button at viewtopic.php
 *
 */
function hook_phpbbfacebookstyle_quickreply()
{
	$quickreply = request_var('quickreply', 0);
	// Chech this first, it's only exist in quickreply_editor.html
	if ($quickreply)
	{
		global $auth;
		global $submit, $error, $data, $redirect_url;

		//	If all this variable exist and aren't empty we assume that the post was submitted successfully.
		if ((isset($error) && isset($submit) && isset($redirect_url) && !empty($redirect_url)) && (!sizeof($error) && $submit))
		{
			// Check the permissions for post approval. Moderators are not affected.
			if ((!$auth->acl_get('f_noapprove', $data['forum_id']) && !$auth->acl_get('m_approve', $data['forum_id']) && empty($data['force_approved_state'])) || (isset($data['force_approved_state']) && !$data['force_approved_state']))
			{
				//	The post need approval, do nothing
			}
			else
			{
				redirect($redirect_url);
				exit();
			}
		}
	}
}

/**
 * Enter description here...
 *
 * @param (object) $phpbb_hook
 */
function hook_phpbbfacebookstyle_session_handler($phpbb_hook)
{
	global $user;

	if ($user->theme['theme_name'] == 'phpBB facebook')
	{
		if (!defined('PHPBB_USE_BOARD_URL_PATH'))
		{
			define('PHPBB_USE_BOARD_URL_PATH', true);
		}
		if (defined('IN_AJAX_STATS') || defined('IN_ADMIN') || defined('STK_ROOT_PATH')){return;}
		if (!defined('STYLE_FACEBOOK'))
		{
			$phpbb_hook->register(array('template', 'display'), 'hook_phpbbfacebookstyle_display', 'last');
		}
	}
}
$phpbb_hook->register('phpbb_user_session_handler', 'hook_phpbbfacebookstyle_session_handler');

?>